==> haskell-pipes-http-1.0.6-763-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-5b8wQOfocSMDTEiNZEorYM
key:                  pipes-http-1.0.6-5b8wQOfocSMDTEiNZEorYM
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  8714af7a4d3f01decdee22d661f62734
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-5b8wQOfocSMDTEiNZEorYM
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    pipes-4.3.16-BeVHqcQKZUkHsDYr9zTHaP

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.6-765-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-44sbfaDlsbW7XTnensoTrn
key:                  pipes-http-1.0.6-44sbfaDlsbW7XTnensoTrn
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  16675236900ebbe2aee51266b1f9a128
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-44sbfaDlsbW7XTnensoTrn
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
    http-client-tls-0.3.6.4-ILttD7UGaFL2zbr7B8I43g
    pipes-4.3.16-rMQ28U3uZnErMwz2lZfKi

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
